==> openshift-model-6.7.0-sources.jar: io/fabric8/openshift/api/model/TLSConfigBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TLSConfigBuilder extends TLSConfigFluentImpl<TLSConfigBuilder> implements VisitableBuilder<TLSConfig,TLSConfigBuilder>{
  public TLSConfigBuilder() {
    this(false);
  }
  public TLSConfigBuilder(Boolean validationEnabled) {
    this(new TLSConfig(), validationEnabled);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TLSConfig(), validationEnabled);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent,TLSConfig instance) {
    this(fluent, instance, false);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent,TLSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCaCertificate(instance.getCaCertificate());
      fluent.withCertificate(instance.getCertificate());
      fluent.withDestinationCACertificate(instance.getDestinationCACertificate());
      fluent.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      fluent.withKey(instance.getKey());
      fluent.withTermination(instance.getTermination());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TLSConfigBuilder(TLSConfig instance) {
    this(instance,false);
  }
  public TLSConfigBuilder(TLSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCaCertificate(instance.getCaCertificate());
      this.withCertificate(instance.getCertificate());
      this.withDestinationCACertificate(instance.getDestinationCACertificate());
      this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      this.withKey(instance.getKey());
      this.withTermination(instance.getTermination());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TLSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public TLSConfig build() {
    TLSConfig buildable = new TLSConfig(fluent.getCaCertificate(),fluent.getCertificate(),fluent.getDestinationCACertificate(),fluent.getInsecureEdgeTerminationPolicy(),fluent.getKey(),fluent.getTermination());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/TLSConfigBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TLSConfigBuilder extends TLSConfigFluent<TLSConfigBuilder> implements VisitableBuilder<TLSConfig,TLSConfigBuilder>{
  public TLSConfigBuilder() {
    this(false);
  }
  public TLSConfigBuilder(Boolean validationEnabled) {
    this(new TLSConfig(), validationEnabled);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TLSConfig(), validationEnabled);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent,TLSConfig instance) {
    this(fluent, instance, false);
  }
  public TLSConfigBuilder(TLSConfigFluent<?> fluent,TLSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new TLSConfig());

    if (instance != null) {
      fluent.withCaCertificate(instance.getCaCertificate());
      fluent.withCertificate(instance.getCertificate());
      fluent.withDestinationCACertificate(instance.getDestinationCACertificate());
      fluent.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      fluent.withKey(instance.getKey());
      fluent.withTermination(instance.getTermination());
      fluent.withCaCertificate(instance.getCaCertificate());
      fluent.withCertificate(instance.getCertificate());
      fluent.withDestinationCACertificate(instance.getDestinationCACertificate());
      fluent.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      fluent.withKey(instance.getKey());
      fluent.withTermination(instance.getTermination());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public TLSConfigBuilder(TLSConfig instance) {
    this(instance,false);
  }
  public TLSConfigBuilder(TLSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new TLSConfig());

    if (instance != null) {
      this.withCaCertificate(instance.getCaCertificate());
      this.withCertificate(instance.getCertificate());
      this.withDestinationCACertificate(instance.getDestinationCACertificate());
      this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      this.withKey(instance.getKey());
      this.withTermination(instance.getTermination());
      this.withCaCertificate(instance.getCaCertificate());
      this.withCertificate(instance.getCertificate());
      this.withDestinationCACertificate(instance.getDestinationCACertificate());
      this.withInsecureEdgeTerminationPolicy(instance.getInsecureEdgeTerminationPolicy());
      this.withKey(instance.getKey());
      this.withTermination(instance.getTermination());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  TLSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public TLSConfig build() {
    TLSConfig buildable = new TLSConfig(fluent.getCaCertificate(),fluent.getCertificate(),fluent.getDestinationCACertificate(),fluent.getInsecureEdgeTerminationPolicy(),fluent.getKey(),fluent.getTermination());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
